# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `rime-api-key` header.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class JobDataContinuousIncrementalTest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'firewall_id': 'str',
        'ct_test_run_ids': 'list[str]',
        'progress': 'RimeContinuousTestJobProgress'
    }

    attribute_map = {
        'firewall_id': 'firewallId',
        'ct_test_run_ids': 'ctTestRunIds',
        'progress': 'progress'
    }

    def __init__(self, firewall_id=None, ct_test_run_ids=None, progress=None):  # noqa: E501
        """JobDataContinuousIncrementalTest - a model defined in Swagger"""  # noqa: E501
        self._firewall_id = None
        self._ct_test_run_ids = None
        self._progress = None
        self.discriminator = None
        if firewall_id is not None:
            self.firewall_id = firewall_id
        if ct_test_run_ids is not None:
            self.ct_test_run_ids = ct_test_run_ids
        if progress is not None:
            self.progress = progress

    @property
    def firewall_id(self):
        """Gets the firewall_id of this JobDataContinuousIncrementalTest.  # noqa: E501


        :return: The firewall_id of this JobDataContinuousIncrementalTest.  # noqa: E501
        :rtype: str
        """
        return self._firewall_id

    @firewall_id.setter
    def firewall_id(self, firewall_id):
        """Sets the firewall_id of this JobDataContinuousIncrementalTest.


        :param firewall_id: The firewall_id of this JobDataContinuousIncrementalTest.  # noqa: E501
        :type: str
        """

        self._firewall_id = firewall_id

    @property
    def ct_test_run_ids(self):
        """Gets the ct_test_run_ids of this JobDataContinuousIncrementalTest.  # noqa: E501


        :return: The ct_test_run_ids of this JobDataContinuousIncrementalTest.  # noqa: E501
        :rtype: list[str]
        """
        return self._ct_test_run_ids

    @ct_test_run_ids.setter
    def ct_test_run_ids(self, ct_test_run_ids):
        """Sets the ct_test_run_ids of this JobDataContinuousIncrementalTest.


        :param ct_test_run_ids: The ct_test_run_ids of this JobDataContinuousIncrementalTest.  # noqa: E501
        :type: list[str]
        """

        self._ct_test_run_ids = ct_test_run_ids

    @property
    def progress(self):
        """Gets the progress of this JobDataContinuousIncrementalTest.  # noqa: E501


        :return: The progress of this JobDataContinuousIncrementalTest.  # noqa: E501
        :rtype: RimeContinuousTestJobProgress
        """
        return self._progress

    @progress.setter
    def progress(self, progress):
        """Sets the progress of this JobDataContinuousIncrementalTest.


        :param progress: The progress of this JobDataContinuousIncrementalTest.  # noqa: E501
        :type: RimeContinuousTestJobProgress
        """

        self._progress = progress

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(JobDataContinuousIncrementalTest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, JobDataContinuousIncrementalTest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `rime-api-key` header.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ArtifactIdentifierSubsetTestMetricIdentifier(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'test_batch_id': 'str',
        'metric': 'str',
        'feature_names': 'list[str]',
        'subset_name': 'str'
    }

    attribute_map = {
        'test_batch_id': 'testBatchId',
        'metric': 'metric',
        'feature_names': 'featureNames',
        'subset_name': 'subsetName'
    }

    def __init__(self, test_batch_id=None, metric=None, feature_names=None, subset_name=None):  # noqa: E501
        """ArtifactIdentifierSubsetTestMetricIdentifier - a model defined in Swagger"""  # noqa: E501
        self._test_batch_id = None
        self._metric = None
        self._feature_names = None
        self._subset_name = None
        self.discriminator = None
        if test_batch_id is not None:
            self.test_batch_id = test_batch_id
        if metric is not None:
            self.metric = metric
        if feature_names is not None:
            self.feature_names = feature_names
        if subset_name is not None:
            self.subset_name = subset_name

    @property
    def test_batch_id(self):
        """Gets the test_batch_id of this ArtifactIdentifierSubsetTestMetricIdentifier.  # noqa: E501

        Uniquely specifies a Test Batch.  # noqa: E501

        :return: The test_batch_id of this ArtifactIdentifierSubsetTestMetricIdentifier.  # noqa: E501
        :rtype: str
        """
        return self._test_batch_id

    @test_batch_id.setter
    def test_batch_id(self, test_batch_id):
        """Sets the test_batch_id of this ArtifactIdentifierSubsetTestMetricIdentifier.

        Uniquely specifies a Test Batch.  # noqa: E501

        :param test_batch_id: The test_batch_id of this ArtifactIdentifierSubsetTestMetricIdentifier.  # noqa: E501
        :type: str
        """

        self._test_batch_id = test_batch_id

    @property
    def metric(self):
        """Gets the metric of this ArtifactIdentifierSubsetTestMetricIdentifier.  # noqa: E501

        The metric name.  # noqa: E501

        :return: The metric of this ArtifactIdentifierSubsetTestMetricIdentifier.  # noqa: E501
        :rtype: str
        """
        return self._metric

    @metric.setter
    def metric(self, metric):
        """Sets the metric of this ArtifactIdentifierSubsetTestMetricIdentifier.

        The metric name.  # noqa: E501

        :param metric: The metric of this ArtifactIdentifierSubsetTestMetricIdentifier.  # noqa: E501
        :type: str
        """

        self._metric = metric

    @property
    def feature_names(self):
        """Gets the feature_names of this ArtifactIdentifierSubsetTestMetricIdentifier.  # noqa: E501

        Human-readable names of the features. Must be sorted lexicographically.  # noqa: E501

        :return: The feature_names of this ArtifactIdentifierSubsetTestMetricIdentifier.  # noqa: E501
        :rtype: list[str]
        """
        return self._feature_names

    @feature_names.setter
    def feature_names(self, feature_names):
        """Sets the feature_names of this ArtifactIdentifierSubsetTestMetricIdentifier.

        Human-readable names of the features. Must be sorted lexicographically.  # noqa: E501

        :param feature_names: The feature_names of this ArtifactIdentifierSubsetTestMetricIdentifier.  # noqa: E501
        :type: list[str]
        """

        self._feature_names = feature_names

    @property
    def subset_name(self):
        """Gets the subset_name of this ArtifactIdentifierSubsetTestMetricIdentifier.  # noqa: E501

        Human-readable name of the feature subset used for the `subset_name` field. This is used to display the subset name on the frontend.  # noqa: E501

        :return: The subset_name of this ArtifactIdentifierSubsetTestMetricIdentifier.  # noqa: E501
        :rtype: str
        """
        return self._subset_name

    @subset_name.setter
    def subset_name(self, subset_name):
        """Sets the subset_name of this ArtifactIdentifierSubsetTestMetricIdentifier.

        Human-readable name of the feature subset used for the `subset_name` field. This is used to display the subset name on the frontend.  # noqa: E501

        :param subset_name: The subset_name of this ArtifactIdentifierSubsetTestMetricIdentifier.  # noqa: E501
        :type: str
        """

        self._subset_name = subset_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ArtifactIdentifierSubsetTestMetricIdentifier, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ArtifactIdentifierSubsetTestMetricIdentifier):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `rime-api-key` header.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class CustomermanagedkeyCustomerManagedKeyConfig(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'key_provider': 'CustomermanagedkeyKeyProvider',
        'kms_key_arn': 'str'
    }

    attribute_map = {
        'key_provider': 'keyProvider',
        'kms_key_arn': 'kmsKeyArn'
    }

    def __init__(self, key_provider=None, kms_key_arn=None):  # noqa: E501
        """CustomermanagedkeyCustomerManagedKeyConfig - a model defined in Swagger"""  # noqa: E501
        self._key_provider = None
        self._kms_key_arn = None
        self.discriminator = None
        if key_provider is not None:
            self.key_provider = key_provider
        self.kms_key_arn = kms_key_arn

    @property
    def key_provider(self):
        """Gets the key_provider of this CustomermanagedkeyCustomerManagedKeyConfig.  # noqa: E501


        :return: The key_provider of this CustomermanagedkeyCustomerManagedKeyConfig.  # noqa: E501
        :rtype: CustomermanagedkeyKeyProvider
        """
        return self._key_provider

    @key_provider.setter
    def key_provider(self, key_provider):
        """Sets the key_provider of this CustomermanagedkeyCustomerManagedKeyConfig.


        :param key_provider: The key_provider of this CustomermanagedkeyCustomerManagedKeyConfig.  # noqa: E501
        :type: CustomermanagedkeyKeyProvider
        """

        self._key_provider = key_provider

    @property
    def kms_key_arn(self):
        """Gets the kms_key_arn of this CustomermanagedkeyCustomerManagedKeyConfig.  # noqa: E501

        The ARN of the AWS KMS key to use as the customer managed key.  # noqa: E501

        :return: The kms_key_arn of this CustomermanagedkeyCustomerManagedKeyConfig.  # noqa: E501
        :rtype: str
        """
        return self._kms_key_arn

    @kms_key_arn.setter
    def kms_key_arn(self, kms_key_arn):
        """Sets the kms_key_arn of this CustomermanagedkeyCustomerManagedKeyConfig.

        The ARN of the AWS KMS key to use as the customer managed key.  # noqa: E501

        :param kms_key_arn: The kms_key_arn of this CustomermanagedkeyCustomerManagedKeyConfig.  # noqa: E501
        :type: str
        """
        if kms_key_arn is None:
            raise ValueError("Invalid value for `kms_key_arn`, must not be `None`")  # noqa: E501

        self._kms_key_arn = kms_key_arn

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CustomermanagedkeyCustomerManagedKeyConfig, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CustomermanagedkeyCustomerManagedKeyConfig):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `rime-api-key` header.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from rime_sdk.swagger.swagger_client.api_client import ApiClient


class NotificationSettingApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def notification_setting_create_notification(self, body, **kwargs):  # noqa: E501
        """CreateNotification  # noqa: E501

        Creates a new notification setting.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.notification_setting_create_notification(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param RimeCreateNotificationRequest body: (required)
        :return: RimeCreateNotificationResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.notification_setting_create_notification_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.notification_setting_create_notification_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def notification_setting_create_notification_with_http_info(self, body, **kwargs):  # noqa: E501
        """CreateNotification  # noqa: E501

        Creates a new notification setting.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.notification_setting_create_notification_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param RimeCreateNotificationRequest body: (required)
        :return: RimeCreateNotificationResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method notification_setting_create_notification" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `notification_setting_create_notification`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Firewall-Api-Key', 'X-Firewall-Auth-Token', 'rime-api-key']  # noqa: E501

        return self.api_client.call_api(
            '/v1/notif-settings', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RimeCreateNotificationResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def notification_setting_delete_notification(self, id_uuid, **kwargs):  # noqa: E501
        """DeleteNotification  # noqa: E501

        Hard-delete a notification setting.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.notification_setting_delete_notification(id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id_uuid: Unique object ID. (required)
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.notification_setting_delete_notification_with_http_info(id_uuid, **kwargs)  # noqa: E501
        else:
            (data) = self.notification_setting_delete_notification_with_http_info(id_uuid, **kwargs)  # noqa: E501
            return data

    def notification_setting_delete_notification_with_http_info(self, id_uuid, **kwargs):  # noqa: E501
        """DeleteNotification  # noqa: E501

        Hard-delete a notification setting.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.notification_setting_delete_notification_with_http_info(id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id_uuid: Unique object ID. (required)
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id_uuid']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method notification_setting_delete_notification" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id_uuid' is set
        if ('id_uuid' not in params or
                params['id_uuid'] is None):
            raise ValueError("Missing the required parameter `id_uuid` when calling `notification_setting_delete_notification`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id_uuid' in params:
            path_params['id.uuid'] = params['id_uuid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Firewall-Api-Key', 'X-Firewall-Auth-Token', 'rime-api-key']  # noqa: E501

        return self.api_client.call_api(
            '/v1/notif-settings/{id.uuid}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def notification_setting_list_notifications(self, **kwargs):  # noqa: E501
        """ListNotifications  # noqa: E501

        Lists notification settings with options to filter by project or the type of notification.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.notification_setting_list_notifications(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param list[str] list_notifications_query_object_types: Specifies a set of object types. Filters results by the specified set of object types.   - OBJECT_TYPE_UNSPECIFIED: Unspecified is an invalid object type - do not use.  - OBJECT_TYPE_PROJECT: Used for notifications associated with an project. The Notification object ID is the Project ID.
        :param list[str] list_notifications_query_object_ids: Specifies a set of object IDs. Filters results by the specified set of object IDs.
        :param str page_token: Specifies a page of the list returned by a ListNotifications query. The ListNotifications query returns a pageToken when there is more than one page of results. Specify either this field or the listNotificationsQuery field.
        :param str page_size: The maximum number of Notification objects to return in a single page.
        :return: RimeListNotificationsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.notification_setting_list_notifications_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.notification_setting_list_notifications_with_http_info(**kwargs)  # noqa: E501
            return data

    def notification_setting_list_notifications_with_http_info(self, **kwargs):  # noqa: E501
        """ListNotifications  # noqa: E501

        Lists notification settings with options to filter by project or the type of notification.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.notification_setting_list_notifications_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param list[str] list_notifications_query_object_types: Specifies a set of object types. Filters results by the specified set of object types.   - OBJECT_TYPE_UNSPECIFIED: Unspecified is an invalid object type - do not use.  - OBJECT_TYPE_PROJECT: Used for notifications associated with an project. The Notification object ID is the Project ID.
        :param list[str] list_notifications_query_object_ids: Specifies a set of object IDs. Filters results by the specified set of object IDs.
        :param str page_token: Specifies a page of the list returned by a ListNotifications query. The ListNotifications query returns a pageToken when there is more than one page of results. Specify either this field or the listNotificationsQuery field.
        :param str page_size: The maximum number of Notification objects to return in a single page.
        :return: RimeListNotificationsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['list_notifications_query_object_types', 'list_notifications_query_object_ids', 'page_token', 'page_size']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method notification_setting_list_notifications" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'list_notifications_query_object_types' in params:
            query_params.append(('listNotificationsQuery.objectTypes', params['list_notifications_query_object_types']))  # noqa: E501
            collection_formats['listNotificationsQuery.objectTypes'] = 'multi'  # noqa: E501
        if 'list_notifications_query_object_ids' in params:
            query_params.append(('listNotificationsQuery.objectIds', params['list_notifications_query_object_ids']))  # noqa: E501
            collection_formats['listNotificationsQuery.objectIds'] = 'multi'  # noqa: E501
        if 'page_token' in params:
            query_params.append(('pageToken', params['page_token']))  # noqa: E501
        if 'page_size' in params:
            query_params.append(('pageSize', params['page_size']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Firewall-Api-Key', 'X-Firewall-Auth-Token', 'rime-api-key']  # noqa: E501

        return self.api_client.call_api(
            '/v1/notif-settings', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RimeListNotificationsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def notification_setting_update_notification(self, body, notification_id_uuid, **kwargs):  # noqa: E501
        """UpdateNotification  # noqa: E501

        Updates an existing notification setting. The ID in the provided notification is used to identify it.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.notification_setting_update_notification(body, notification_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param NotifsettingsNotificationIdUuidBody body: (required)
        :param str notification_id_uuid: Unique object ID. (required)
        :return: RimeUpdateNotificationResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.notification_setting_update_notification_with_http_info(body, notification_id_uuid, **kwargs)  # noqa: E501
        else:
            (data) = self.notification_setting_update_notification_with_http_info(body, notification_id_uuid, **kwargs)  # noqa: E501
            return data

    def notification_setting_update_notification_with_http_info(self, body, notification_id_uuid, **kwargs):  # noqa: E501
        """UpdateNotification  # noqa: E501

        Updates an existing notification setting. The ID in the provided notification is used to identify it.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.notification_setting_update_notification_with_http_info(body, notification_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param NotifsettingsNotificationIdUuidBody body: (required)
        :param str notification_id_uuid: Unique object ID. (required)
        :return: RimeUpdateNotificationResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'notification_id_uuid']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method notification_setting_update_notification" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `notification_setting_update_notification`")  # noqa: E501
        # verify the required parameter 'notification_id_uuid' is set
        if ('notification_id_uuid' not in params or
                params['notification_id_uuid'] is None):
            raise ValueError("Missing the required parameter `notification_id_uuid` when calling `notification_setting_update_notification`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'notification_id_uuid' in params:
            path_params['notification.id.uuid'] = params['notification_id_uuid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Firewall-Api-Key', 'X-Firewall-Auth-Token', 'rime-api-key']  # noqa: E501

        return self.api_client.call_api(
            '/v1/notif-settings/{notification.id.uuid}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RimeUpdateNotificationResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `rime-api-key` header.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class RimeGetValidateModelTaskStatusResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'resp': 'ValidationValidateModelResponse',
        'job_metadata': 'RimeJobMetadata'
    }

    attribute_map = {
        'resp': 'resp',
        'job_metadata': 'jobMetadata'
    }

    def __init__(self, resp=None, job_metadata=None):  # noqa: E501
        """RimeGetValidateModelTaskStatusResponse - a model defined in Swagger"""  # noqa: E501
        self._resp = None
        self._job_metadata = None
        self.discriminator = None
        if resp is not None:
            self.resp = resp
        if job_metadata is not None:
            self.job_metadata = job_metadata

    @property
    def resp(self):
        """Gets the resp of this RimeGetValidateModelTaskStatusResponse.  # noqa: E501


        :return: The resp of this RimeGetValidateModelTaskStatusResponse.  # noqa: E501
        :rtype: ValidationValidateModelResponse
        """
        return self._resp

    @resp.setter
    def resp(self, resp):
        """Sets the resp of this RimeGetValidateModelTaskStatusResponse.


        :param resp: The resp of this RimeGetValidateModelTaskStatusResponse.  # noqa: E501
        :type: ValidationValidateModelResponse
        """

        self._resp = resp

    @property
    def job_metadata(self):
        """Gets the job_metadata of this RimeGetValidateModelTaskStatusResponse.  # noqa: E501


        :return: The job_metadata of this RimeGetValidateModelTaskStatusResponse.  # noqa: E501
        :rtype: RimeJobMetadata
        """
        return self._job_metadata

    @job_metadata.setter
    def job_metadata(self, job_metadata):
        """Sets the job_metadata of this RimeGetValidateModelTaskStatusResponse.


        :param job_metadata: The job_metadata of this RimeGetValidateModelTaskStatusResponse.  # noqa: E501
        :type: RimeJobMetadata
        """

        self._job_metadata = job_metadata

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RimeGetValidateModelTaskStatusResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RimeGetValidateModelTaskStatusResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `rime-api-key` header.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class RimeLimitStatus(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'limit': 'RimeLicenseLimit',
        'limit_status': 'RimeLimitStatusStatus',
        'limit_value': 'str',
        'current_value': 'str'
    }

    attribute_map = {
        'limit': 'limit',
        'limit_status': 'limitStatus',
        'limit_value': 'limitValue',
        'current_value': 'currentValue'
    }

    def __init__(self, limit=None, limit_status=None, limit_value=None, current_value=None):  # noqa: E501
        """RimeLimitStatus - a model defined in Swagger"""  # noqa: E501
        self._limit = None
        self._limit_status = None
        self._limit_value = None
        self._current_value = None
        self.discriminator = None
        if limit is not None:
            self.limit = limit
        if limit_status is not None:
            self.limit_status = limit_status
        if limit_value is not None:
            self.limit_value = limit_value
        if current_value is not None:
            self.current_value = current_value

    @property
    def limit(self):
        """Gets the limit of this RimeLimitStatus.  # noqa: E501


        :return: The limit of this RimeLimitStatus.  # noqa: E501
        :rtype: RimeLicenseLimit
        """
        return self._limit

    @limit.setter
    def limit(self, limit):
        """Sets the limit of this RimeLimitStatus.


        :param limit: The limit of this RimeLimitStatus.  # noqa: E501
        :type: RimeLicenseLimit
        """

        self._limit = limit

    @property
    def limit_status(self):
        """Gets the limit_status of this RimeLimitStatus.  # noqa: E501


        :return: The limit_status of this RimeLimitStatus.  # noqa: E501
        :rtype: RimeLimitStatusStatus
        """
        return self._limit_status

    @limit_status.setter
    def limit_status(self, limit_status):
        """Sets the limit_status of this RimeLimitStatus.


        :param limit_status: The limit_status of this RimeLimitStatus.  # noqa: E501
        :type: RimeLimitStatusStatus
        """

        self._limit_status = limit_status

    @property
    def limit_value(self):
        """Gets the limit_value of this RimeLimitStatus.  # noqa: E501


        :return: The limit_value of this RimeLimitStatus.  # noqa: E501
        :rtype: str
        """
        return self._limit_value

    @limit_value.setter
    def limit_value(self, limit_value):
        """Sets the limit_value of this RimeLimitStatus.


        :param limit_value: The limit_value of this RimeLimitStatus.  # noqa: E501
        :type: str
        """

        self._limit_value = limit_value

    @property
    def current_value(self):
        """Gets the current_value of this RimeLimitStatus.  # noqa: E501


        :return: The current_value of this RimeLimitStatus.  # noqa: E501
        :rtype: str
        """
        return self._current_value

    @current_value.setter
    def current_value(self, current_value):
        """Sets the current_value of this RimeLimitStatus.


        :param current_value: The current_value of this RimeLimitStatus.  # noqa: E501
        :type: str
        """

        self._current_value = current_value

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RimeLimitStatus, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RimeLimitStatus):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
